API Reference
=============

pyjags module
-------------

This is a convenience module that imports all names from submodules.
Equivalent to ::

  from pyjags.model import *
  from pyjags.modules import *


pyjags.model
------------

.. automodule:: pyjags.model
  :members:

pyjags.modules
--------------

.. automodule:: pyjags.modules
  :members:

